# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

#global prerel rc1
%global pythonver %(python -c "import sys; print sys.version[:3]" 2>/dev/null || echo none)

Summary:	Library providing XML and HTML support
Name:		libxml2
Version:	2.9.1
Release:	%{?prerel:0.}2.0.%{?prerel:%{prerel}.}cf.%{__distinit}%{__distvers}
License:	MIT
Group:		Development/Libraries
URL:		http://xmlsoft.org/
Source0:	ftp://xmlsoft.org/libxml2/libxml2-%{version}%{?prerel:-%{prerel}}.tar.gz
Patch0:		libxml2-multilib.patch
Patch1:		libxml2-2.9.0-do-not-check-crc.patch
Patch100:	libxml2-2.7.4-sles.patch
Patch101:	libxml2-2.9.1-pygenerator.patch
Patch102:	libxml2-2.9.1-python26.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-root-%(id -nu)
BuildRequires:	pkgconfig python python-devel zlib-devel

# Drop bogus provide for python shared object
%global __provides_exclude ^libxml2mod\\.so

%description
This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DtDs, either
at parse time or later once the document has been modified. The output
can be a simple SAX stream or and in-memory DOM like representations.
In this case one can use the built-in XPath and XPointer implementation
to select sub-nodes or ranges. A flexible Input/Output mechanism is
available, with existing HTTP and FTP modules and combined to an
URI library.

%package devel
Summary:	Libraries, includes, etc. to develop XML and HTML applications
Group:		Development/Libraries
Requires:	libxml2%{?_isa} = %{version}-%{release}
Requires:	zlib-devel
Requires:	pkgconfig

%description devel
Libraries, include files, etc you can use to develop XML applications.
This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DtDs, either
at parse time or later once the document has been modified. The output
can be a simple SAX stream or and in-memory DOM like representations.
In this case one can use the built-in XPath and XPointer implementation
to select sub-nodes or ranges. A flexible Input/Output mechanism is
available, with existing HTTP and FTP modules and combined to an
URI library.

%package static
Summary:	Static library for libxml2
Group:		Development/Libraries
Requires:	libxml2%{?_isa} = %{version}-%{release}

%description static
Static library for libxml2 provided for specific uses or shaving a few
microseconds when parsing, do not link to them for generic purpose packages.

%package python
Summary:	Python bindings for the libxml2 library
Group:		Development/Libraries
Requires:	libxml2%{?_isa} = %{version}-%{release}

%description python
The libxml2-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libxml2 library to manipulate XML files.

This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DTDs, either
at parse time or later once the document has been modified.

# SuSE 10 needs this to build debuginfo
%if "%{__distinit}" == "sles"
%debug_package
%endif

%prep
%setup -q
%patch0 -p1

# Workaround for #877567 - Very weird bug gzip decompression bug in "recent" libxml2 versions
%patch1 -p1 -b .do-not-check-crc

# Fix up docs paths for SLES
%if "%{__distinit}" == "sles"
%patch100 -p1 -b .sles
%endif

# Fix python build for python 2.3
%if "%{pythonver}" == "2.3"
%patch101
%endif

# Fix python build for python 2.6
%patch102

# Fix bogus exec permissions
find . \( -name '*.c' -o -name '*.py' \) -exec chmod 644 {} \;

# We'll ship compressed versions of some documentation
gzip -9c < doc/libxml2-api.xml > doc/libxml2-api.xml.gz

%build
%configure
make %{_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} INSTALL="install -p" install

# Remove files we don't want packaged
rm -rf %{buildroot}%{_libdir}/*.la

# We'll package the documentation ourselves
rm -rf %{buildroot}%{_datadir}/doc/libxml2-%{version}/
rm -rf %{buildroot}%{_datadir}/doc/libxml2-python-%{version}/

# Multiarch crazyness on timestamp differences or Makefile/binaries for examples
touch -m --reference=%{buildroot}%{_includedir}/libxml2/libxml/parser.h %{buildroot}%{_bindir}/xml2-config

%check
# make check / make runtests seem to have a failure on i386 on F-7 and similarly old releases
# make runtests
make testall

# Clean up examples before shipping them as %%doc
# Can't do this until test suite has run
make -C doc/examples clean
rm -rf doc/examples/{.deps,.memdump,Makefile}

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS NEWS README Copyright TODO
%{_libdir}/lib*.so.*
%{_bindir}/xmllint
%{_bindir}/xmlcatalog
%{_mandir}/man1/xmllint.1*
%{_mandir}/man1/xmlcatalog.1*
%{_mandir}/man3/libxml.3*

%files devel
%defattr(-,root,root,-)
%doc doc/*.html doc/html doc/*.gif doc/*.png
%doc doc/tutorial doc/libxml2-api.xml.gz
# Note: examples/writer.xml and examples/testWriter.c explicitly encoded as ISO-8859-1
%doc doc/examples
%doc %dir %{_datadir}/gtk-doc/html/libxml2/
%doc %{_datadir}/gtk-doc/html/libxml2/*.devhelp
%doc %{_datadir}/gtk-doc/html/libxml2/*.html
%doc %{_datadir}/gtk-doc/html/libxml2/*.png
%doc %{_datadir}/gtk-doc/html/libxml2/*.css
%{_bindir}/xml2-config
%{_libdir}/lib*.so
%{_libdir}/*.sh
%{_libdir}/pkgconfig/libxml-2.0.pc
%{_includedir}/libxml2/
%{_datadir}/aclocal/libxml.m4
%{_mandir}/man1/xml2-config.1*

%files static
%defattr(-,root,root,-)
%{_libdir}/*a

%files python
%defattr(-,root,root,-)
%doc python/TODO
%doc python/libxml2class.txt
%doc python/tests/*.py
%doc doc/*.py
%doc doc/python.html
%{_libdir}/python%{pythonver}/site-packages/libxml2.py*
%{_libdir}/python%{pythonver}/site-packages/drv_libxml2.py*
%{_libdir}/python%{pythonver}/site-packages/libxml2mod.so
%exclude %{_libdir}/python%{pythonver}/site-packages/libxml2mod.a
%exclude %{_libdir}/python%{pythonver}/site-packages/libxml2mod.la

%changelog
* Mon Aug  5 2013 Paul Howarth <paul@city-fan.org> 2.9.1-2.0.cf
- rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Apr 19 2013 Paul Howarth <paul@city-fan.org> 2.9.1-1.0.cf
- update to 2.9.1
  - a couple more API entry points
  - compatibility with python3
  - a lot of bug fixes
- maintain timestamps where possible
- add patch to fix python 2.6 compatibility (Gnome Bug #698364)
- update patch for python 2.3 compatibility

* Mon Feb 11 2013 Paul Howarth <paul@city-fan.org> 2.9.0-4.0.cf
- don't ship examples/.deps in devel package

* Mon Nov 19 2012 Paul Howarth <paul@city-fan.org> 2.9.0-3.0.cf
- workaround for crc/len check failure (#877567)

* Thu Oct 11 2012 Paul Howarth <paul@city-fan.org> 2.9.0-2.0.cf
- only ship the library documentation in the -devel package, not the main
  package (#864731)
- don't ship the old ChangeLog file

* Tue Sep 11 2012 Paul Howarth <paul@city-fan.org> 2.9.0-1.0.cf
- update to 2.9.0 final
  - a few new API entry points
  - more resilient push parser mode
  - a lot of portability improvements
  - faster XPath evaluation
  - a lot of bug fixes and smaller improvements

* Sun Aug 19 2012 Paul Howarth <paul@city-fan.org> 2.9.0-0.1.0.rc1.cf
- upstream release candidate 1 of 2.9.0
  - introduce a small API change, but ABI compatible, see
    https://mail.gnome.org/archives/xml/2012-August/msg00005.html
  - patches for php, gcc/libjava and evolution-data-connector are upstream
  - in case of problems, contact Daniel Veillard <veillard@redhat.com>
  - many bug fixes including security aspects and small improvements

* Thu Jul 24 2012 Paul Howarth <paul@city-fan.org> 2.8.0-2.0.cf
- rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed May 23 2012 Paul Howarth <paul@city-fan.org> 2.8.0-1.0.cf
- new release 2.8.0
  - add lzma compression support
  - various documentation updates
  - lots of portability fixes, particularly for Windows targets
  - lots of bug fixes and other improvements
- drop patches no longer needed
- add %%clean section and run the test suite there
- drop support for python 2.2

* Fri Jan 13 2012 Paul Howarth <paul@city-fan.org> 2.7.8-10.0.cf
- add XPath hardening patch from upstream (#732335)
- fix missing error status in XPath evaluation (CVE-2011-2834)
- make sure the parser returns when getting a Stop order (CVE-2011-3905)
- fix an allocation error when copying entities (CVE-2011-3919)

* Wed Nov 16 2011 Paul Howarth <paul@city-fan.org> 2.7.8-9.0.cf
- fix a heap-based buffer overflow caused by an off by one error in the
  encoding code (#724906, CVE-2011-0216)

* Sat Aug  6 2011 Paul Howarth <paul@city-fan.org> 2.7.8-8.0.cf
- fix dist tag for CentOS 6 and Scientific Linux

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> 2.7.8-7.0.cf
- fix a heap-based buffer overflow caused by adding a new namespace node to an
  existing nodeset or merging nodesets in XPath (#709750, CVE-2011-1944)
- drop bogus provide for python shared object
- nobody else likes macros for commands

* Fri Mar  4 2011 Paul Howarth <paul@city-fan.org> 2.7.8-6.0.cf
- fix a double free in XPath (#665965, CVE-2010-4494)

* Tue Feb  8 2011 Paul Howarth <paul@city-fan.org> 2.7.8-5.0.cf
- rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Nov  5 2010 Paul Howarth <paul@city-fan.org> 2.7.8-4.0.cf
- resync with Rawhide

* Thu Nov  4 2010 Paul Howarth <paul@city-fan.org> 2.7.8-2.0.cf
- new release 2.7.8
  - various bug fixes, including potential crashes
  - new non-destructive formatting option
  - date parsing updated to RFC 5646
- add patch to fix shared library versioning
- add patch to support build of python bindings with python < 2.4

* Wed Jul 28 2010 Paul Howarth <paul@city-fan.org> 2.7.7-2.1.cf
- rebuild for python 2.7 in Rawhide

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> 2.7.7-2.0.cf
- fix dist tag for RHEL-6 Beta

* Mon Mar 15 2010 Paul Howarth <paul@city-fan.org> 2.7.7-1.0.cf
- new release 2.7.7
  - fix serious trouble with zlib >= 1.2.4
  - xmllint new option --xpath
  - various HTML parser improvements
  - includes a number of bug fixes

* Thu Feb 25 2010 Paul Howarth <paul@city-fan.org> 2.7.6-2.0.cf
- dist tag for Rawhide no longer needs special-casing

* Wed Oct  7 2009 Paul Howarth <paul@city-fan.org> 2.7.6-1.0.cf
- new release 2.7.6 (restore thread support off by default in 2.7.5)

* Fri Sep 25 2009 Paul Howarth <paul@city-fan.org> 2.7.5-1.0.cf
- new release 2.7.5
  - little data at startup patch upstreamed
  - fix a couple of Relax-NG validation problems
  - a few more fixes

* Tue Sep 15 2009 Paul Howarth <paul@city-fan.org> 2.7.4-2.0.cf
- fix a problem with little data at startup affecting inkscape (#523002)

* Thu Sep 10 2009 Paul Howarth <paul@city-fan.org> 2.7.4-1.0.cf
- new release 2.7.4, with security patches now upstream
- lots of other fixes: see http://xmlsoft.org/news.html
- update SLES patch to remove fuzz

* Wed Aug 12 2009 Paul Howarth <paul@city-fan.org> 2.7.3-4.0.cf
- two patches for parsing problems CVE-2009-2414 and CVE-2009-2416

* Fri Jul 31 2009 Paul Howarth <paul@city-fan.org> 2.7.3-3.0.cf
- rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar  2 2009 Paul Howarth <paul@city-fan.org> 2.7.3-2.0.cf
- rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Feb 24 2009 Paul Howarth <paul@city-fan.org> 2.7.3-1.2.cf
- force creation of debuginfo on SLES

* Mon Feb 23 2009 Paul Howarth <paul@city-fan.org> 2.7.3-1.1.cf
- add SLES support in dist tag macros
- add patch to fix up docs directories for SLES

* Tue Jan 20 2009 Paul Howarth <paul@city-fan.org> 2.7.3-1.0.CF
- new release 2.7.3, with security patches now upstream
- limit default max size of text nodes
- special parser mode for PHP
- bug fixes and more compiler checks
- source is now in "libxml2" directory on ftp server at xmlsoft.org

* Wed Dec 10 2008 Paul Howarth <paul@city-fan.org> 2.7.2-7.0.CF
- rebuild for python 2.6 on Rawhide

* Wed Dec  3 2008 Paul Howarth <paul@city-fan.org> 2.7.2-6.0.CF
- buildreq pkgconfig to get pkgconfig auto-provides (#473978)

* Mon Nov 17 2008 Paul Howarth <paul@city-fan.org> 2.7.2-3
- two patches for size overflow problems: CVE-2008-4225 (#470480) and
  CVE-2008-4226 (#470466)

* Fri Oct 31 2008 Paul Howarth <paul@city-fan.org> 2.7.2-2
- import from Fedora
- make subpackages package require same-arch version of base package
- use full pathnames for build-time command paths
- install using DESTDIR rather than deprecated %%makeinstall macro
- remove bogus exec permissions from source files
- don't package static python binding

* Fri Oct  3 2008 Daniel Veillard <veillard@redhat.com> 2.7.2-1.fc10
- new release 2.7.2
- Fixes the known problems in 2.7.1
- increase the set of options when saving documents

* Thu Oct  2 2008 Daniel Veillard <veillard@redhat.com> 2.7.1-2.fc10
- fix a nasty bug in 2.7.x, http://bugzilla.gnome.org/show_bug.cgi?id=554660

* Mon Sep  1 2008 Daniel Veillard <veillard@redhat.com> 2.7.1-1.fc10
- fix python serialization which was broken in 2.7.0
- Resolve: rhbz#460774

* Sat Aug 30 2008 Daniel Veillard <veillard@redhat.com> 2.7.0-1.fc10
- upstream release of 2.7.0
- switch to XML 1.0 5th edition
- switch to RFC 3986 for URI parsing
- better entity handling
- option to remove hardcoded limitations in the parser
- more testing
- a new API to allocate entity nodes
- and lot of fixes and clanups

* Mon Aug 25 2008 Daniel Veillard <veillard@redhat.com> 2.6.32-4.fc10
- fix for entities recursion problem
- Resolve: rhbz#459714

* Fri May 30 2008 Daniel Veillard <veillard@redhat.com> 2.6.32-3.fc10
- cleanup based on Fedora packaging guidelines, should fix #226079
- separate a -static package

* Thu May 15 2008 Daniel Veillard <veillard@redhat.com> 2.6.32-2.fc10
- try to fix multiarch problems like #440206

* Tue Apr  8 2008 Daniel Veillard <veillard@redhat.com> 2.6.32-1.fc9
- upstream release 2.6.32 see http://xmlsoft.org/news.html
- many bug fixed upstream

* Wed Feb 20 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.6.31-2
- Autorebuild for GCC 4.3

* Fri Jan 11 2008 Daniel Veillard <veillard@redhat.com> 2.6.31-1.fc9
- upstream release 2.6.31 see http://xmlsoft.org/news.html
- many bug fixed upstream

* Thu Aug 23 2007 Daniel Veillard <veillard@redhat.com> 2.6.30-1
- upstream release 2.6.30 see http://xmlsoft.org/news.html
- many bug fixed upstream

* Tue Jun 12 2007 Daniel Veillard <veillard@redhat.com> 2.6.29-1
- upstream release 2.6.29 see http://xmlsoft.org/news.html
- many bug fixed upstream

* Wed May 16 2007 Matthias Clasen <mclasen@redhat.com> 2.6.28-2
- Bump revision to fix N-V-R problem

* Tue Apr 17 2007 Daniel Veillard <veillard@redhat.com> 2.6.28-1
- upstream release 2.6.28 see http://xmlsoft.org/news.html
- many bug fixed upstream

* Thu Dec  7 2006 Jeremy Katz <katzj@redhat.com> - 2.6.27-2
- rebuild against python 2.5

* Wed Oct 25 2006 Daniel Veillard <veillard@redhat.com> 2.6.27-1
- upstream release 2.6.27 see http://xmlsoft.org/news.html
- very large amount of bug fixes reported upstream

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.6.26-2.1.1
- rebuild

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.6.26-2.1
- rebuild

* Wed Jun  7 2006 Daniel Veillard <veillard@redhat.com> 2.6.26-2
- fix bug #192873
* Tue Jun  6 2006 Daniel Veillard <veillard@redhat.com> 2.6.26-1
- upstream release 2.6.26 see http://xmlsoft.org/news.html

* Tue Jun  6 2006 Daniel Veillard <veillard@redhat.com>
- upstream release 2.6.25 broken, do not ship !

